Loglikehood function under independent censoring
LikCopInd(theta, resData, X, W, lhat, cumL, dist)Maximized log-likelihood value
Estimated parameter values/initial values for finite dimensional parameters
Data matrix with three columns; Z = the observed survival time, d1 = the censoring indicator of T and d2 = the censoring indicator of C.
Data matrix with covariates related to T
Data matrix with covariates related to C. First column of W should be ones
The estimated hazard function obtained from the output of SolveLI.
The estimated cumulative hazard function from the output of SolveLI.
The distribution to be used for the dependent censoring C. Only two distributions are allowed, i.e, Weibull
and lognormal distributions. With the value "Weibull" as the
default.
@importFrom stats nlminb pnorm qnorm sd