This function defines the maximum likelihood used to estimate the control function in the case of a continuous endogenous variable.
LikGamma1(gamma, Z, M)Returns the log-likelihood function corresponding to the data,
evaluated at the point gamma.
Vector of coefficients in the linear model used to estimate the control function.
Endogenous covariate.
Design matrix, containing an intercept, the exogenous covariates and the instrumental variable.