This function computes the critical value following the algorithm of Section 4.3 in Bei (2024).
get.cvLLn(
BetaI.r,
data,
t,
hp,
c,
r,
par.space,
inst.func.evals = NULL,
alpha = 0.95
)The critical value for the test statistic.
Matrix containing in its columns the minimizers of the S-function leading to the test statistic.
Data frame.
Time point of interest. Also allowed to be a vector of time points (used in estimating the model under assumed time- independent coefficients).
List of hyperparameters.
Projection vector.
Result of projection of parameter vector onto c.
Bounds on the parameter space.
Matrix of precomputed instrumental function
evaluations for each observation in the data set. If NULL, the
evaluations will be computed during execution of this function. Default is
inst.func.evals = NULL.
Confidence level.
Bei, X. (2024). Local linearieation based subvector inference in moment inequality models. Journal of Econometrics. 238:105549-